function [namemodel, MyFolder2]=DvLRunSIMLAMainFile(a, e, dpth, llchain)

%---------------------------------------------------------------------------
%        GENERAL INPUT
%---------------------------------------------------------------------------
rhost=7850;             %Density steel [kg/m^3]
rhosw=1026;             %Density seawater [kg/m^3]
rhocorr=1300;           %Density corrosion/asphalt layer [kg/m^3]
rhoconc=2500;           %Density concrete layer [kg/m^3]
rhocont=800;            %Density content [kg/m^3]
Em=2.1*10^11;
G=79.3*10^9; 

%---------------------------------------------------------------------------
% HER M DU TA INN DE FORSKJELLIGE VERDIENE FOR:
% - Anchor distributed loads
%---------------------------------------------------------------------------

[lfchain, ChaDiam, BrLoad, ChMass, A, B, C, D, E, F, G1]=DvLReadingAnchorInput(a); 

if llchain==0;
    lchain=lfchain;
else
    lchain=llchain;
end

[NameLine, namemodel]=DvLfilenameNew(a, e, lchain);
dpth2=200; %If inspecting any other depths, change this value 

[AncLine1, AncLine2, AncLine3, AncLine4, AncLine5, AnchMLine1, AnchMLine2,...
    AnchMLine3, y3, z3]=DvLCoorAnchor(A, E, F, a, rhost, rhosw, dpth2, e, G1, lchain);

[CableMatrix, CabMSub, CableMat, nelem, CM]=DvLCoorCable(lchain, dpth, rhost,...
    rhosw, Em, ChaDiam, ChMass, y3, z3, G);

[CL1, CL2, CL3, CL4, CL5, CL6, CL7, CL8, CL9, CL10, CL11, ChaRad, SpringS]=DvLCoorCableLines(CableMatrix,...
    CabMSub, ChMass, ChaDiam, CableMat, nelem, CM, lchain);

[VSLine]=DvLExtraLine(e);

[ROTS, DYNS, SLDS, SLDCN1, SLDCN2, SLDBC1, SLDBC2, SLDBC3, DYNB1, DYNB2, DYN1, DYN2, DYN3,...
    STATROT, DYN15, DYN4]=DvLwriteDynL(e);

[DS1, DS2, DS3, DS4, DS5, DS6, DS7, DS8, DS9, DS10, DS11, DS12,...
    DS13, DS14, DS15, DS16, DS17]=DvLdisplacementback(e);

nodepropsanchor=DvLAnchorModelling(G1, ChaRad);

%---------------------------------------------------------------------------
% CREATING A NEW DIRECTORY WITH MODEL NAME
%---------------------------------------------------------------------------
dir1='D:\Analysis\DvL';
dir2=namemodel;
dir3=[dir1 '\' dir2];
if ~exist(dir3, 'dir');
    % Folder does not exist so create it.
    mkdir('D:\Analysis\DvL',namemodel);
end

%---------------------------------------------------------------------------
% CREATING A NEW .SIF FILE AND WRITING penetration.txt AND seabed.txt
% Here the new .sif file is written to the new directy, and a new .raf file
% is created to ensure that any old .raf files are deleted
%---------------------------------------------------------------------------
fid   = fopen('C:\Analysis\InputFileShortDvL\1113.sif', 'r');   
MyFolder1='D:\Analysis\DvL'; 
MyFolder2=fullfile(MyFolder1, namemodel);
BaseFileName=sprintf('%s.sif',namemodel);
BaseFileNameRaf=sprintf('%s.raf',namemodel);

NewFile=fullfile(MyFolder2, BaseFileName);
NewFileRaf=fullfile(MyFolder2, BaseFileNameRaf);

penetrationandseabed=penandsea(MyFolder2,dpth);
fout = fopen(NewFile, 'w');

%---------------------------------------------------------------------------
%                   ENDRE LINES
%---------------------------------------------------------------------------
J=1;

writtenLines=DvLwritingLines(NameLine, J, e, fid, fout, AncLine1, AncLine2, AncLine3, AncLine4, AncLine5,...
    AnchMLine1, AnchMLine2, AnchMLine3, CL1, CL2, CL3, CL4, CL5, CL6, CL7, CL8, CL9, CL10, CL11,...
    DYNS, SLDS, SLDCN1, SLDCN2, SLDBC1, SLDBC2, SLDBC3, DYNB1, DYNB2, DYN1, DYN2, DYN3,...
    STATROT, VSLine, DYN15, DYN4, DS1, DS2, DS3, DS4, DS5, DS6,...
    DS7, DS8, DS9, DS10, DS11, DS12, DS13, DS14, DS15, DS16, DS17, nodepropsanchor, SpringS);

%---------------------------------------------------------------------------
% TO RUN SIMLA - STATIC ANALYSIS
%---------------------------------------------------------------------------
Run='running.bat';
MyFolderR='C:\Analysis\RunSIMLADepthVsLength';
RunFile=fullfile(MyFolderR, Run);
frun = fopen(RunFile, 'wt');
cmnd='"C:\\Marintek\\SIMLA\\bin\\simla.exe" -n '; 
NewFileR=fullfile(MyFolder2, namemodel);
f = strrep(NewFileR, '\', '\\'); 
cmnd2=[cmnd, f];
cmnd3='pushd ';
fr=strrep(MyFolder2, '\', '\\');
cmnd4=sprintf('%s %s \n', cmnd3, fr);

fprintf(frun, cmnd4);
fprintf(frun, cmnd2);
fclose(frun);

!running.bat

%---------------------------------------------------------------------------
% TO WRITE THE DYNAMIC LINES
%---------------------------------------------------------------------------
dynrun=1;
fid  = fopen('C:\Analysis\InputFileShortDvL\1113.sif', 'r') ; 
fout = fopen(NewFile, 'wt');

J=3;
writtenLines=DvLwritingLines(NameLine, J, e, fid, fout, AncLine1, AncLine2, AncLine3, AncLine4, AncLine5,...
    AnchMLine1, AnchMLine2, AnchMLine3, CL1, CL2, CL3, CL4, CL5, CL6, CL7, CL8, CL9, CL10, CL11,...
    DYNS, SLDS, SLDCN1, SLDCN2, SLDBC1, SLDBC2, SLDBC3, DYNB1, DYNB2, DYN1, DYN2, DYN3,...
    STATROT, VSLine, DYN15, DYN4, DS1, DS2, DS3, DS4, DS5, DS6,...
    DS7, DS8, DS9, DS10, DS11, DS12, DS13, DS14, DS15, DS16, DS17, nodepropsanchor, SpringS);

%---------------------------------------------------------------------------
% TO RUN SIMLA - DYNAMIC ANALYSIS
%---------------------------------------------------------------------------
!running.bat

%---------------------------------------------------------------------------
% CREATING DESIRE OUTPUT .MPF FILES
%---------------------------------------------------------------------------
[mpffiles, mpffilesnopr, OutPutFold]=DvLcreateMPF(MyFolder2, namemodel); 
n = DvLlinecount(mpffiles);
DvLPlotCreator(mpffiles, mpffilesnopr, n, OutPutFold, lchain, namemodel, z3);

end

