function [CabMSub, CableMat, nelem, CM]=CoorCable(lchain, dpth, rhost, rhosw, Em, ChaDiam, ChaMass, y3, z3, G);

%------------------------------------------------------------------%
% Calculates properties of the chain: geometry, stiffness
%------------------------------------------------------------------%
rc=(ChaDiam/1000)/2;        %Radius cable [m]
Ac=2*(pi()*rc^2);           %Area circular assumption for one section[m^2]
Ic=2*pi*rc^4/4;             %Second moment of inertia for two circular sections[m^4]
EA=Em*Ac*10^-6;             %Axial stiffness for two circular sections [MN]
EI=Em*Ic*(10^-6);           %Bending stiffness [MNm^2] 

Ip=2*pi*rc^4/2;             %Polar moment of inertia [m^4]
GIT=G*Ip*10^-6;				%Torsion stiffness [MNm^2]

Ec=Em/10^6;					%Young's modulus [MN]
Gc=G/10^6;					%Shear modulus [MPa]	
CableMat=[EA EI Ec GIT Gc];

%------------------------------------------------------------------%
% Calculates properties of the chain: mass, starting coordinates, 
% length of elements and coordinates of chain
%------------------------------------------------------------------%
volumecab=ChaMass/rhost; %Volume cable [m^3/m]
bouycab=volumecab*rhosw;    %Bouyancy cable [kg/m]
CabMSub=ChaMass-bouycab; %Submerged cable mass [kg/m]

%Starting coordinates
dz=z3;
dy=sqrt((lchain^2)-(dz^2));
ycortop=y3+dy;
theta=asin(dz/lchain);

%Length of each element and coordinates
link=6*ChaDiam/1000;
CCM=zeros(9,2);
CCM(1,1)=y3;
CCM(1,2)=z3;


nelem=zeros(3);
CM=zeros(4,3);
CM(1,1)=y3;
CM(1,2)=z3;
ltop=0;
nelemttop=0;
dellchain=lchain/3;
nelem=dellchain/link;
CM(1,3)=round(50001+nelem);
nrest=round(1001-nelem);
CM(2,3)=50000+round(nelem)+round((2/3)*nrest);
CM(3,3)=50000+round(nelem)+nrest-nelemttop;
CM(4,3)=CM(3,3)+nelemttop;
for i=1:3;
    hypl=(dellchain*i)-ltop;
    CM(i+1,1)=y3-(cos(theta)*hypl);
    CM(i+1,2)=z3-(sin(theta)*hypl);
    CM(5,1)=y3-(cos(theta)*(hypl+ltop));
    CM(5,2)=z3-(sin(theta)*(hypl+ltop));
end

end