function [PMDry, PMSub, Dout, Rout, Th, Tout, PipeMat]=PipeMass(Em, G, rhost, rhosw, rhocorr, rhoconc, rhocont, b, tcorr, tconc)

%------------------------------------------------------------------%
% Calculates properties of pipeline: Geometry
%------------------------------------------------------------------%
rsout=b/2;							%Radius outer steel pipe [m]
t=b/35;								%Thickness of steel pipe [m]
Th=t;								%Thickness [m]
Rout=rsout+tcorr+tconc;				%Total outer radius pipe [m]
Dout=Rout*2;						%Total outer diameter [m]
Tout=Th+tcorr+tconc;				%Total thickness pipe [m]
rin=rsout-Th;						%Total radius inner pipe [m] 

%------------------------------------------------------------------%
% Calculates properties of pipeline: Mass
%------------------------------------------------------------------%
msteel = (pi/4)*((b^2)-(b-(2*t))^2)*rhost;				%Mass steel pipe [kg/m]
mcorr=((pi()*(rsout+tcorr)^2)-(pi*rsout^2))*rhocorr; 	%Mass corrosion layer [kg/m]
mconc=((pi()*(rsout+tcorr+tconc)^2)-(pi*(rsout+tcorr)^2))*rhoconc; %Mass concrete layer [kg/m]
mcont=(pi()*rin^2)*rhocont; 							%Mass of content [kg/m]

pipebuoyancy = (pi)*((rsout+tcorr+tconc)^2)*rhosw;		%Pipe buoyancy [kg/m]
PMDry=msteel+mcorr+mconc+mcont;                   		%Mass entire pipe [kg/m]
PMSub=PMDry-pipebuoyancy                       			%Submerged mass of pipe [kg/m]

%------------------------------------------------------------------%
% Calculates properties of pipeline: Stiffness
%------------------------------------------------------------------%

Ipipe=(pi*(rsout^4-(rin^4)))/4;         %Second moment of inertia [m^4]
Api=(pi()*((rsout)^2-(rin)^2));   		%Cross-section area [m^2]              

EApi=Api*Em*10^-6;       	            %Axial stiffness pipe [MN]
EIpipe=Em*Ipipe*10^-3;                  %Bending stiffness pipe [Nm^2] Due to rigid body made extra stiff

Ipi=(pi/2)*((rsout^4)-rin^4);			%Polar moment of inertia [m^4]
GIT=G*Ipi*10^-6;						%Torsion stiffness [MNm^2]
PipeMat=[EApi EIpipe GIT];
end

