function [namemodel, MyFolder2]=RunSIMLAMainFile(a, binp, c, d, e, dpth, llchain)
%---------------------------------------------------------------------------
%           ASSUMED INPUT ABOUT PIPELINE MATERIAL
%   Values for tcorr, tconc, rhocorr, rhoconc from Svein Svik
%---------------------------------------------------------------------------
tcorr=0.006;        %Asphalt layer [m]
tconc=0.045;        %Concrete layer [m]

%---------------------------------------------------------------------------
%        GENERAL INPUT
%---------------------------------------------------------------------------
rhost=7850;             %Density steel [kg/m^3]
rhosw=1026;             %Density seawater [kg/m^3]
rhocorr=1300;           %Density corrosion/asphalt layer [kg/m^3]
rhoconc=2500;           %Density concrete layer [kg/m^3]
rhocont=800;            %Density content [kg/m^3]
Em=2.1*10^11;
G=79.3*10^9; 

%---------------------------------------------------------------------------
% HER M DU TA INN DE FORSKJELLIGE VERDIENE FOR:
% - Anchor distributed loads
%---------------------------------------------------------------------------
b=binp*0.0254;      %Diameter changes from inches to meters

[lfchain, ChaDiam, BrLoad, ChMass, A, B, C, D, E, F, G1]=ReadingAnchorInput(a); 

%If different anchor length is chosen in InputRun.m, this will apply said length 
if llchain==0;
    lchain=lfchain;
else
    lchain=llchain;
end

[NameLine, namemodel]=filenameNew(a, binp, c, d, e, dpth, lchain);

[AncLine1, AncLine2, AncLine3, AncLine4, AncLine5, AnchMLine1, AnchMLine2,...
    AnchMLine3, y3, z3]=CoorAnchor(A, E, F, a, rhost, rhosw, dpth, e, G1);

[CabMSub, CableMat, nelem, CM]=CoorCable(lchain, dpth, rhost,...
    rhosw, Em, ChaDiam, ChMass, y3, z3, G);

[CL1, CL2, CL3, CL4, CL5, CL6, CL7, CL8, CL9, CL10, CL11, ChaRad]=CoorCableLines(CabMSub,...
    ChMass, ChaDiam, CableMat, CM);
  
[PMDry, PMSub, Dout, Rout, Th, Tout, PipeMat]=PipeMass(Em, G, rhost, rhosw, rhocorr,...
    rhoconc, rhocont, b, tcorr, tconc);

[PL1, PL2, PL3, PL4, BCRPL1, BCRPL2, BCRPL3, BCRPL4, ROL1, ROL2, ROL3, ROL4]=PipeLine(Rout,...
    Dout, Th, Tout, PMDry, PMSub, dpth, PipeMat, Em, G); 

[VSLine, SpanLine, RotLine]=ExtraLine(d, e, c);

[ROTS, DYNS, SLDS, SLDCN1, SLDCN2, SLDFR1, SLDBC1, SLDBC2, SLDBC3,...
    DYNB1, DYNB2, DYN1, DYN2, DYN3, STATROT, DYN15, DYN4]=writeDynL(e);

[DS1, DS2, DS3, DS4, DS5, DS6, DS7, DS8, DS9, DS10, DS11, DS12,...
    DS13, DS14, DS15, DS16, DS17, DSEXTRA]=displacementback(e);

nodepropsanchor=AnchorModelling(G1, ChaRad);

%---------------------------------------------------------------------------
% CREATING A NEW DIRECTORY WITH MODEL NAME
%---------------------------------------------------------------------------
dir1='D:\Analysis';
dir2=namemodel;
dir3=[dir1 '\' dir2];
if ~exist(dir3, 'dir');
    % Folder does not exist so create it.
    mkdir('D:\Analysis',namemodel);
end

%---------------------------------------------------------------------------
% CREATING A NEW .SIF FILE AND WRITING penetration.txt AND seabed.txt
% Here the new .sif file is written to the new directy, and a new .raf file
% is created to ensure that any old .raf files are deleted
%---------------------------------------------------------------------------
fid   = fopen('C:\Analysis\InputFileShort\1113.sif', 'r');   
MyFolder1='D:\Analysis'; 
MyFolder2=fullfile(MyFolder1, namemodel);
BaseFileName=sprintf('%s.sif',namemodel);
BaseFileNameRaf=sprintf('%s.raf',namemodel);

NewFile=fullfile(MyFolder2, BaseFileName);
NewFileRaf=fullfile(MyFolder2, BaseFileNameRaf);

penetrationandseabed=penandsea(MyFolder2,dpth);
fout = fopen(NewFile, 'w');

%---------------------------------------------------------------------------
%                   WRITE LINES
%---------------------------------------------------------------------------
J=1;

writtenLines=writingLines(NameLine, J, c, e, fid, fout, AncLine1, AncLine2, AncLine3, AncLine4, AncLine5,...
    AnchMLine1, AnchMLine2, AnchMLine3, CL1, CL2, CL3, CL4, CL5, CL6, CL7, CL8, CL9, CL10, CL11,...
    PL1, PL2, PL3, PL4, BCRPL1, BCRPL2, BCRPL3, BCRPL4, ROL1, ROL2, ROL3, ROL4, ROTS, DYNS, SLDS,...
   SLDCN1, SLDCN2,SLDFR1, SLDBC1, SLDBC2, SLDBC3, DYNB1, DYNB2, DYN1, DYN2, DYN3,...
    STATROT, VSLine, SpanLine, RotLine, DYN15, DYN4, DS1, DS2, DS3, DS4, DS5, DS6,...
    DS7, DS8, DS9, DS10, DS11, DS12, DS13, DS14, DS15, DS16, DS17, nodepropsanchor, DSEXTRA);

%---------------------------------------------------------------------------
% TO RUN SIMLA - STATIC ANALYSIS
%---------------------------------------------------------------------------
Run='running.bat';
MyFolderR='C:\Analysis\RunSIMLA';
RunFile=fullfile(MyFolderR, Run);
frun = fopen(RunFile, 'wt');
cmnd='"C:\\Marintek\\SIMLA\\bin\\simla.exe" -n '; 
NewFileR=fullfile(MyFolder2, namemodel);
f = strrep(NewFileR, '\', '\\'); 
cmnd2=[cmnd, f];
cmnd3='pushd ';
fr=strrep(MyFolder2, '\', '\\');
cmnd4=sprintf('%s %s \n', cmnd3, fr);

fprintf(frun, cmnd4);
fprintf(frun, cmnd2);
fclose(frun);

!running.bat

%---------------------------------------------------------------------------
 %TO ROTATE PIPE TO ASSURE PROPER ATTACK ANGLE
%---------------------------------------------------------------------------
fid   = fopen('C:\Analysis\InputFileShort\1113.sif', 'r') ; 
fout = fopen(NewFile, 'w');

J=2;
writtenLines=writingLines(NameLine, J, c, e, fid, fout, AncLine1, AncLine2, AncLine3, AncLine4, AncLine5,...
    AnchMLine1, AnchMLine2, AnchMLine3, CL1, CL2, CL3, CL4, CL5, CL6, CL7, CL8, CL9, CL10, CL11,...
    PL1, PL2, PL3, PL4, BCRPL1, BCRPL2, BCRPL3, BCRPL4, ROL1, ROL2, ROL3, ROL4, ROTS, DYNS, SLDS,...
    SLDCN1, SLDCN2, SLDFR1, SLDBC1, SLDBC2, SLDBC3, DYNB1, DYNB2, DYN1, DYN2, DYN3,...
    STATROT, VSLine, SpanLine, RotLine, DYN15, DYN4, DS1, DS2, DS3, DS4, DS5, DS6,...
    DS7, DS8, DS9, DS10, DS11, DS12, DS13, DS14, DS15, DS16, DS17,...
    nodepropsanchor, DSEXTRA);

%---------------------------------------------------------------------------
% TO RUN SIMLA - ROTATING PIPE STATIC ANALYSIS
%---------------------------------------------------------------------------
!running.bat

%---------------------------------------------------------------------------
% WRITING THE DYNAMIC LINES
%---------------------------------------------------------------------------
dynrun=1;
fid   = fopen('C:\Analysis\InputFileShort\1113.sif', 'r') ; 
fout = fopen(NewFile, 'w');

J=3;
writtenLines=writingLines(NameLine, J, c, e, fid, fout, AncLine1, AncLine2, AncLine3, AncLine4, AncLine5,...
    AnchMLine1, AnchMLine2, AnchMLine3, CL1, CL2, CL3, CL4, CL5, CL6, CL7, CL8, CL9, CL10, CL11,...
    PL1, PL2, PL3, PL4, BCRPL1, BCRPL2, BCRPL3, BCRPL4, ROL1, ROL2, ROL3, ROL4, ROTS, DYNS, SLDS,...
    SLDCN1, SLDCN2, SLDFR1, SLDBC1, SLDBC2, SLDBC3, DYNB1, DYNB2, DYN1, DYN2, DYN3,...
    STATROT, VSLine, SpanLine, RotLine, DYN15, DYN4, DS1, DS2, DS3, DS4, DS5, DS6,...
    DS7, DS8, DS9, DS10, DS11, DS12, DS13, DS14, DS15, DS16, DS17, nodepropsanchor, DSEXTRA);

%---------------------------------------------------------------------------
% RUNNING SIMLA - DYNAMIC ANALYSIS
%---------------------------------------------------------------------------
!running.bat

%---------------------------------------------------------------------------
% WRITING SLIDING LINES
%---------------------------------------------------------------------------
dynrun=1;

J=4;
if c~=90;
    fid   = fopen('C:\Analysis\InputFileShort\1113.sif', 'r') ; 
    fout = fopen(NewFile, 'w');
    writtenLines=writingLines(NameLine, J, c, e, fid, fout, AncLine1, AncLine2, AncLine3, AncLine4, AncLine5,...
        AnchMLine1, AnchMLine2, AnchMLine3, CL1, CL2, CL3, CL4, CL5, CL6, CL7, CL8, CL9, CL10, CL11,...
        PL1, PL2, PL3, PL4, BCRPL1, BCRPL2, BCRPL3, BCRPL4, ROL1, ROL2, ROL3, ROL4, ROTS, DYNS, SLDS,...
        SLDCN1, SLDCN2, SLDFR1, SLDBC1, SLDBC2, SLDBC3, DYNB1, DYNB2, DYN1, DYN2, DYN3,...
        STATROT, VSLine, SpanLine, RotLine, DYN15, DYN4, DS1, DS2, DS3, DS4, DS5, DS6,...
        DS7, DS8, DS9, DS10, DS11, DS12, DS13, DS14, DS15, DS16, DS17, nodepropsanchor, DSEXTRA);

     %---------------------------------------------------------------------------
     % TO RUN SIMLA - DYNAMIC SLIDING ANALYSIS
     %---------------------------------------------------------------------------
        %!running.bat
end
end

